<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>عارض صور ديبين</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>اﻹصدار:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>صورة</translation>
    </message>
    <message>
        <source>images</source>
        <translation>صور</translation>
    </message>
    <message>
        <source>album</source>
        <translation>ألبوم</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>ألبومات</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>إدارة المزامنة</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>المزامنة:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>غير مسمى</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>تم استيرادها مؤخراً</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>مفضلتي</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>هل أنت متأكد من حذف هذا اﻷلبوم؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>رجوع</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>مفضلتي</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>الخط الزمني</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>إضافة</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>يمكنك إضافة دليل المزامنة أو سحب الصور وإسقاطها إلى المخطط الزمني </translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>غير مسمى</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة التسمية</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>عارض صور ديبين</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>الصور</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>هل أنت متأكد من إضافة الصور إلى اﻷلبوم؟</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>مزامنة وإنشاء</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>المزامنة</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>هل تريد بالتأكيد الإضافة إلى قائمة المزامنة وإنشاء الألبوم باسم هذا المجلد؟ </translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>تم التصدير بنجاح </translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>فشل التصدير </translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>هل أنت متأكد من نقل الصور إلى سلة المحذوفات؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من اﻷلبوم</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزالة من المفضلة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>إضافة</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>يمكنك إضافة دليل المزامنة أو سحب الصور وإسقاطها إلى المخطط الزمني </translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>إضافة  إلى الألبوم</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>إضافة إلى ألبوم جديد</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>فتح الدليل</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>ليس لديك الصلاحية لرؤية الصورة</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>تاريخ التعديل</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>حجم الملف</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>مساحة اﻷلوان</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>وضع التعرض</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>برنامج التعرض</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>زمن التعرض </translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>فلاش </translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>فتحة العدسة</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>البعد البؤري </translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO </translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>أقصى فتحة </translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>وضع القياس </translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>توازن اللون الأبيض </translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>تعويض الفلاش</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>طراز الكاميرا</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>طراز العدسة</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Millimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Centimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>إسدال</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>تبديل</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>انزلاق</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>حلقة</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>تحديد دليل</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>تم تعطيل هذا الدليل عن المزامنة</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>إضافة مجلد </translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>إدارة مزامنة الدليل</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>قائمة الدليل فارغة</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>إلغاء المزامنة</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>الصور</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>تم حذف الجهاز</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>الدليل  غير موجود</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>يتم الحساب...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>عرض الصورة</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>ألبوم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>إنهاء العرض</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من اﻷلبوم</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزالة من المفضلة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>الشاشة السابقة</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>الشاشة التالية</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة التسمية</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>اختصارات العرض</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>يرجى إضافة اختصار جديد</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>الاختصارات</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>عرض الصورة</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>ألبوم</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>استعادة الافتراضيات</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>إنهاء العرض</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من اﻷلبوم</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزالة من المفضلة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة التسمية</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>إنهاء العرض</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>إيقاف/تشغيل</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>إعدادات الشريحة</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>تاثيرات الانتقال</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>المدة</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>مدة التبديل</translation>
    </message>
    <message>
        <source>second</source>
        <translation>ثانية</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>رجوع</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>إدارة الصورة</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>مفضلتي</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>لم يتم العثور على صورة</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation> %1 صورة</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation> %1 صور</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>إدارة المزامنة</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>المزامنة:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>ألبوم</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>إضافة</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>يمكنك إضافة دليل المزامنة أو سحب الصور وإسقاطها إلى المخطط الزمني </translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>إضافة  إلى الألبوم</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>إضافة إلى ألبوم جديد</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>نسخ إلى الحافظة </translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزالة من المفضلة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>إعدادات الشريحة</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>التأثير</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>المدة</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>الاختصارات</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>ألبوم</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>مفضلتي</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>تم استيرادها مؤخراً</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation> عارض الصور من ديبين : مدير للصور٫ عصري و سلس.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>يتميز بادارة الصور٫ عرض الصور و التعديل البسيط عليها.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>سمة داكنة</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>الاطار الزمني</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>إضافة  إلى الألبوم</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>إضافة إلى ألبوم جديد</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>الخروج من الشاشة الكاملة</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من اﻷلبوم</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزالة من المفضلة</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>إظهار نافذة التنقل </translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>إخفاء نافذة التنقل </translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>